Module: AthenaClientHelper
- Defined in:
- lib/efset_test_helper/efset_apps/athena_client_helper.rb
Instance Method Summary collapse
- #complete_efset_listening ⇒ Object
- #complete_efset_reading ⇒ Object
-
#complete_express ⇒ Object
Answer test.
- #complete_express1604 ⇒ Object
- #confirm_audio_check ⇒ Object
-
#next_task ⇒ Object
Goes to next task and confirms if there are pending answers.
-
#play_icon_visible? ⇒ Boolean
Answer test helpers.
- #select_radio(index) ⇒ Object
Instance Method Details
#complete_efset_listening ⇒ Object
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/efset_test_helper/efset_apps/athena_client_helper.rb', line 27 def complete_efset_listening skip_instructions confirm_audio_check select_radio(1) next_task 2.times do confirm_audio_check next_task end end |
#complete_efset_reading ⇒ Object
21 22 23 24 25 |
# File 'lib/efset_test_helper/efset_apps/athena_client_helper.rb', line 21 def complete_efset_reading skip_instructions select_radio(1) 3.times {next_task} end |
#complete_express ⇒ Object
Answer test
9 10 11 12 13 |
# File 'lib/efset_test_helper/efset_apps/athena_client_helper.rb', line 9 def complete_express confirm_audio_check select_radio(1) 2.times {next_task} end |
#complete_express1604 ⇒ Object
15 16 17 18 19 |
# File 'lib/efset_test_helper/efset_apps/athena_client_helper.rb', line 15 def complete_express1604 select_radio(2) continue_next_task.click 15.times {next_task} end |
#confirm_audio_check ⇒ Object
47 48 49 50 51 52 53 54 |
# File 'lib/efset_test_helper/efset_apps/athena_client_helper.rb', line 47 def confirm_audio_check audio_check_title.wait_until_present(15) wait_until_visible(play_icon) sleep 1 play_icon.click sleep 1 audio_check_yes.when_present(15).click end |
#next_task ⇒ Object
Goes to next task and confirms if there are pending answers
57 58 59 60 61 62 63 64 |
# File 'lib/efset_test_helper/efset_apps/athena_client_helper.rb', line 57 def next_task continue_next_task.wait_until_present scroll_to_element(continue_next_task) continue_next_task.click sleep 1 confirm_next_task.click sleep 2 end |
#play_icon_visible? ⇒ Boolean
Answer test helpers
42 43 44 45 |
# File 'lib/efset_test_helper/efset_apps/athena_client_helper.rb', line 42 def play_icon_visible? play_icon.wait_until_present(15) play_icon.visible? end |
#select_radio(index) ⇒ Object
66 67 68 69 |
# File 'lib/efset_test_helper/efset_apps/athena_client_helper.rb', line 66 def select_radio(index) wait_until_visible(task_instructions) athena_client_iframe.radios[index].click end |